@@ -1,5 +1,5 @@
 #!/usr/bin/perl
-# $Id: mplayer.pl,v 1.12 2006/02/07 12:43:17 khlut Exp $
+# $Id: mplayer.pl,v 1.14 2006/02/13 17:42:46 khlut Exp $
 # Bind mplayer and mencoder with HTML object
 # ElphelOgm is used to receive and record rtp mjpeg video
 #
@@ -213,7 +213,8 @@ sub rtpcmd{
 	&& "ElphelOgm -a$1 -p$2 -s2000000";
 }
 
-print "pause=0\n", # list of control variables
+print "debug=1\n", # list of control variables
+      "pause=0\n",
       "play=1\n",
       "save=\n",
       "fps=\n",
@@ -229,7 +230,7 @@ while (<STDIN>){
     }
     s/'/'\\''/g; #'
     ($x,$y) = split '=', $_, 2;
-    $x='href' if($x eq 'src');
+    $x='href' if($x eq 'src' || $x eq 'SRC');
     $v{$x}=$y;
     if("$_" eq "run=1"){
 	$OPTS="";
